import setuptools

setuptools.setup(
    name="passwordP",                     # This is the name of the package
    version="1.0.1.1",                        # The initial release version
    author="Nipun dogra",                     # Full name of the author
    description="password generator package",
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),    # List of all python modules to be installed
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],                                      # Information to filter the project on PyPi website
    python_requires='>=3.6',                # Minimum version requirement of the package
    py_modules=["quicksample"],             # Name of the python package
    install_requires=[]                     # Install other dependencies if any
)



#!/usr/bin/env python
# coding: utf-8

# In[5]:


import random
import string

def generate_pass():

    # using random for range
    len=random.randint(6, 12)

    # using string to generate characters
    lower=string.ascii_lowercase
    upper=string.ascii_uppercase
    num=string.digits

    # to select at least one lower, one upper, one number
    password=random.choice(lower)+random.choice(upper)+random.choice(num)

    # filling password with remaining length
    password+=''.join(random.choices(lower+upper+num,k=len-3))

    # shuffling the password by creating a list
    password_list=list(password)
    random.shuffle(password_list)
    password=''.join(password_list)
    return password



# In[ ]:




